@@ -146,12 +146,13 @@ class CATM(scpi_CMW500):
         self._send("CONFigure:LTE:SIGN:DMODe {}".format(dmode))
         self._send("CONFigure:LTE:SIGN:BAND OB{}".format(bandnum))
     def HandOver_to_other_Band(self,band_num:str):
-        TDDorFDD = "TDD"
+        TDDorFDD = "FDD"
+        BandWidth ="KEEP"
         if int(band_num) in self.TDD_BAND:
             TDDorFDD = "TDD"
-        else:
-            TDDorFDD = "FDD"
-        self._send("PREPare:LTE:SIGN:HANDover:ENHanced {},OB{},KEEP,KEEP,KEEP".format(TDDorFDD,band_num))
+        if band_num in ["31","72","87","88"]:
+            BandWidth= "B050"
+        self._send("PREPare:LTE:SIGN:HANDover:ENHanced {},OB{},KEEP,{},KEEP".format(TDDorFDD,band_num,BandWidth))
         self._send("CALL:LTE:SIGN:PSWitched:ACTion HANDover")#CONNect
     def MeasInit(self):
         self._send("CONFigure:LTE:SIGN:UL:PUSCh:TPC:SET MAXPower")
@@ -210,3 +211,81 @@ class NB(scpi_CMW500):
             return True
         else:
             return False
+    def NB_BandSet(self,bandnum):
+        self._send("CONFigure:NIOT:SIGN:BAND OB{}".format(bandnum))
+    def NB_UplinkNominalPower(self,power=33.8):
+        self._send("CONFigure:NIOT:SIGN:UL:NPUSch:ULNPower {}".format(power))
+    def NB_UlSubcarrierSpacing(self,SK:str="S15K"):
+        '''
+        S3K75 | S15K 
+        '''
+        self._send("CONFigure:NIOT:SIGN:CELL:SCSPacing {}".format(SK))
+    def NB_LossSet(self,loss=1):
+        self._send("CONFigure:NIOT:SIGN:RFSettings:EATTenuation:INPut {}".format(loss))
+    def NB_GetChannel(self):
+        return self._query("CONFigure:NIOT:SIGN:RFSettings:CHANnel:UL?")
+    def SIGN_ON(self,OnOff=True):
+        SwitchKey="OFF"
+        if OnOff:
+            SwitchKey="ON"
+        self._send("SOURce:NIOT:SIGN:CELL:STATe {}".format(SwitchKey))
+    def Instr_MEAS_ON(self):
+        # self._send("ABORt:LTE:MEAS:MEValuation")
+        # time.sleep(1)
+        self._send("ROUTe:NIOT:MEAS:SCENario:CSPath \'NB-IoT Sig1\'")
+        self._send("INITiate:NIOT:MEAS:MEValuation")
+        print("等待5s MEAS ON")
+        time.sleep(5)
+    def MeasInit(self):
+        self._send("CONFigure:NIOT:MEAS:PRACh:REPetition CONTinuous")
+        time.sleep(2)
+    def GetTxPower(self):
+        for idx in range(5):
+            try:
+                data:str = self._query("FETCh:NIOT:MEAS:MEValuation:MODulation:AVERage?")
+                TxPowerAVERage=data.split(",")[11]
+                return float(TxPowerAVERage)
+            except:
+                pass
+            time.sleep(1)
+        raise Exception("Tx Power获取失败")
+class WCDMA(scpi_CMW500):
+    def __init__(self):
+        super().__init__()
+    def SetBand(self,band_num):
+        self._send("CONFigure:WCDMa:SIGN:CARRier:BAND OB{}".format(band_num))
+    def SIGN_ON(self):
+        self._send("SOURce:WCDMa:SIGN:CELL:STATe ON")
+        time.sleep(10)
+    def MeasInit(self):
+        self._send("ROUTe:WCDMa:MEAS:SCENario:CSPath \'WCDMA Sig1\'")
+    def Instr_MEAS_ON(self):
+        self._send("INITiate:WCDMa:MEAS:MEValuation")
+    def CSWitch(self):
+        self._send("CALL:WCDMa:SIGN:CSWitched:ACTion CONNect")
+        for idx in range(5):
+            if self._query("FETCh:WCDMa:SIGN:CSWitched:STATe?","CEST")[0]:
+                return True
+        return False
+    def QCWitch(self):
+        print(self._query("FETCh:WCDMa:SIGN:CSWitched:STATe?"))#REG 注册上 CEST 连接上CS
+
+        #CONFigure:WCDMa:SIGN:UL:TPC:SET ALL1
+        #
+    def SetLoss(self,loss):
+        self._send("CONFigure:WCDMa:SIGN:RFSettings:CARRier:EATTenuation:INPut {}".format(loss))
+    def GetTxPower(self):
+        for idx in range(5):
+            try:
+                data:str = self._query("FETCh:WCDMa:MEAS:MEValuation:LIST:MODulation:AVERage?")
+                TxPowerAVERage=data.split(",")[-1]
+                return float(TxPowerAVERage)
+            except:
+                pass
+            time.sleep(1)
+        raise Exception("Tx Power获取失败")
+    def GetChannel(self):
+        return self._query("CONFigure:WCDMa:SIGN:RFSettings:CARRier:CHANnel:DL?")
+    def HandOverToOtherBand(self,band_num):
+        self._send("PREPare:WCDMa:SIGN:HANDover:EXTernal:WCDMa OB{},KEEP".format(band_num))
+        self._send("CALL:WCDMa:SIGN:CSWitched:ACTion HANDover")#CONNect
\ No newline at end of file
