@@ -1,7 +1,7 @@
 from distutils.core import setup
 import setuptools
 setup(name='DlxTestPack',  #打包后的包文件名
-      version='1.2',
+      version='1.3',
       description='UsedForSimcom AutoTest,Used environment python3.8.10', #说明
       author='hardfood',
       author_email='mdzzdyxc@163.com',
@@ -14,7 +14,7 @@ setup(name='DlxTestPack',  #打包后的包文件名
                   'DlxTestPack.TkPackByMe.fix','DlxTestPack.TkPackByMe.sqlite_api',
                   'DlxTestPack.TkPackByMe.time_test'],   #你要打包的文件
       install_requires=[
-        'configobj','pyvisa','subprocess','pyserial'
+        'configobj','pyvisa','pyserial'
     ],
 )
 #python setup.py build
